Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5164)

Unified Diff: chrome/browser/storage_monitor/storage_monitor_linux.h

Issue 12382005: Rename RemovableDeviceNotifications=>StorageMonitor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/storage_monitor/storage_monitor_linux.h
diff --git a/chrome/browser/storage_monitor/removable_device_notifications_linux.h b/chrome/browser/storage_monitor/storage_monitor_linux.h
similarity index 80%
rename from chrome/browser/storage_monitor/removable_device_notifications_linux.h
rename to chrome/browser/storage_monitor/storage_monitor_linux.h
index 2c4a75612fa9bc50c4194ae5c9448eaf2efb8b16..490d950c54ac22d025e323af0f60b7d2415f5afb 100644
--- a/chrome/browser/storage_monitor/removable_device_notifications_linux.h
+++ b/chrome/browser/storage_monitor/storage_monitor_linux.h
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// RemovableDeviceNotificationsLinux listens for mount point changes, notifies
// listeners about the addition and deletion of media devices, and
// answers queries about mounted devices.
#ifndef CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_LINUX_H_
#define CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_LINUX_H_
#if defined(OS_CHROMEOS)
#error "Use the ChromeOS-specific implementation instead."
@@ -39,15 +39,15 @@ typedef void (*GetDeviceInfoFunc)(const base::FilePath& device_path,
namespace chrome {
-class RemovableDeviceNotificationsLinux
+class StorageMonitorLinux
: public StorageMonitor,
- public base::RefCountedThreadSafe<RemovableDeviceNotificationsLinux,
+ public base::RefCountedThreadSafe<StorageMonitorLinux,
content::BrowserThread::DeleteOnFileThread> {
public:
// Should only be called by browser start up code. Use GetInstance() instead.
- explicit RemovableDeviceNotificationsLinux(const base::FilePath& path);
+ explicit StorageMonitorLinux(const base::FilePath& path);
- // Must be called for RemovableDeviceNotificationsLinux to work.
+ // Must be called for StorageMonitorLinux to work.
void Init();
// Finds the device that contains |path| and populates |device_info|.
@@ -62,20 +62,20 @@ class RemovableDeviceNotificationsLinux
protected:
// Only for use in unit tests.
- RemovableDeviceNotificationsLinux(const base::FilePath& path,
- GetDeviceInfoFunc getDeviceInfo);
+ StorageMonitorLinux(const base::FilePath& path,
+ GetDeviceInfoFunc getDeviceInfo);
// Avoids code deleting the object while there are references to it.
// Aside from the base::RefCountedThreadSafe friend class, and derived
// classes, any attempts to call this dtor will result in a compile-time
// error.
- virtual ~RemovableDeviceNotificationsLinux();
+ virtual ~StorageMonitorLinux();
virtual void OnFilePathChanged(const base::FilePath& path, bool error);
private:
- friend class base::RefCountedThreadSafe<RemovableDeviceNotificationsLinux>;
- friend class base::DeleteHelper<RemovableDeviceNotificationsLinux>;
+ friend class base::RefCountedThreadSafe<StorageMonitorLinux>;
+ friend class base::DeleteHelper<StorageMonitorLinux>;
friend struct content::BrowserThread::DeleteOnThread<
content::BrowserThread::FILE>;
@@ -141,9 +141,9 @@ class RemovableDeviceNotificationsLinux
// points.
MountPriorityMap mount_priority_map_;
- DISALLOW_COPY_AND_ASSIGN(RemovableDeviceNotificationsLinux);
+ DISALLOW_COPY_AND_ASSIGN(StorageMonitorLinux);
};
} // namespace chrome
-#endif // CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_LINUX_H_
+#endif // CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_LINUX_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// RemovableDeviceNotificationsLinux listens for mount point changes, notifies
-// listeners about the addition and deletion of media devices, and
-// answers queries about mounted devices.
+// StorageMonitorLinux listens for mount point changes, notifies listeners
+// about the addition and deletion of media devices, and answers queries about
+// mounted devices.
-#ifndef CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_LINUX_H_
-#define CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_LINUX_H_
+#ifndef CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_LINUX_H_
+#define CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_LINUX_H_
#if defined(OS_CHROMEOS)
#error "Use the ChromeOS-specific implementation instead."